import request from '/@/utils/request';
import { toFormData } from '/@/utils/util';

//#region ====================== knowledge ======================

export interface KnowledgeRes {
	json_ok: boolean;
	question: string;
	answer_type: string;
	knowledge: KnowledgeData[];
}

export interface KnowledgeData {
	answer: string;
	contexts: Context[];
}

export interface Context {
	page_content: string;
	metadata: Metadata;
}

export interface Metadata {
	Title?: string;
}

//#endregion

//#region ====================== RecordSet ======================
export interface RecordSetRes {
	json_ok: boolean;
	question: string;
	answer_type: string;
	values: RecordSetValues;
}

export interface RecordSetValues {
	names: string[];
	values: Array<Array<any>>;
	type: string;
	title: string;
}

//#endregion
/**
 * @summary 获取历史操作
 */
export const GetHistory = async (req: any = request) => {
	return req({
		url: '/chat/get_history',
		method: 'POST',
	});
};

/**
 * @summary
 */
export const GetSampleList = async (req: any = request) => {
	return req({
		url: '/chat/get_sample_list',
		method: 'POST',
	});
};

/**
 * @summary description
 */
export const QuestionAi = async (params, req: any = request) => {
	const formData = toFormData(params);
	return req({
		url: '/chat/question',
		method: 'POST',
		data: formData,
		headers: {
			'Content-Type': 'multipart/form-data',
		},
	});
};

/**
 * @summary description
 */
export const GetLLMList = async (req: any = request) => {
	return req({
		url: '/llm/llm/get_llm_list',
		method: 'POST',
	});
};

/**
 * @summary description
 */
export const SetLLM = async (params, req: any = request) => {
	const formData = toFormData(params);

	return req({
		url: '/llm/set_llm',
		method: 'POST',
		data: formData,
		headers: {
			'Content-Type': 'multipart/form-data',
		},
	});
};

/**
 * @summary  获取主场景
 */
export const getSectionList = async (req: any = request) => {
	return req({
		url: '/section/get_section_a_list',
		method: 'POST',
	});
};
/**
 * @summary  获取单个次场景
 */
export const getSectionByIdList = async (params, req: any = request) => {
	return req({
		url: '/section/get_section_b_list',
		method: 'POST',
		data: params,
		headers: {
			'Content-Type': 'application/x-www-form-urlencoded',
		},
	});
};
/**
 * @summary  获取全部次场景
 */
export const getSectionByAllList = async (req: any = request) => {
	return req({
		url: '/section/get_section_list',
		method: 'POST',
	});
};
/**
 * @summary description
 */
export const CreateHistoryGroup = async (params, req: any = request) => {
	return req({
		url: '/history/create_history_group',
		method: 'POST',
		data: params,
		headers: {
			'Content-Type': 'application/x-www-form-urlencoded',
		},
	});
};


export const GetHistoryGroups = async (params, req:any = request) => {
	return req({
	  url: "/history/get_history_groups",
	  method: "POST",
	  data: params,
	  headers: {
		  'Content-Type': 'application/x-www-form-urlencoded',
	  },
	});
};


  

export const QueryHistoryGroup = async (params, req:any = request) => {
	return req({
	  url: "/history/query_history_detail",
	  method: "POST",
	  data: params,
	  headers: {
		  'Content-Type': 'application/x-www-form-urlencoded',
	  },
	});
  };

  // 获取AI对话测试例子列表
export const getSelectSample = async (params, req: any = request) => {
	return req({
		url: '/section/get_section_sample',
		method: 'POST',
		data: params,
		headers: {
			'Content-Type': 'application/x-www-form-urlencoded',
		},
	});
};


export const GetHistoryAnswer= async (params, req:any = request) => {
	return req({
	  url: "/history/get_history_answer",
	  method: "POST",
	  data: params,
	  headers: {
		  'Content-Type': 'application/x-www-form-urlencoded',
	  },
	});
  };


  export const QueryHistoryDetail = async (params, req:any = request) => {
	return req({
	  url: "/history/query_history_detail",
	  method: "POST",
	  data: params,
	  headers: {
		  'Content-Type': 'application/x-www-form-urlencoded',
	  },
	});
  };